@@ -1,7 +1,7 @@
 package App::depak;
 
 our $DATE = '2017-07-14'; # DATE
-our $VERSION = '0.56'; # VERSION
+our $VERSION = '0.57'; # VERSION
 
 use 5.010001;
 use strict;
@@ -396,7 +396,7 @@ sub _test {
         my $output = Capture::Tiny::capture_merged(
             sub {
                 IPC::System::Options::system({log=>0, shell=>0}, @cmd);
-                $exit = $?;
+                $exit = $? >> 8;
             }
         );
         my $expected_exit = $case->{exit_code} // 0;
@@ -865,6 +865,11 @@ sub depak {
         File::Path::remove_tree($tempdir);
     }
 
+    if ($self->{test}) {
+        log_info("Testing ...");
+        $self->_test;
+    }
+
     if ($self->{input_file_is_stdin}) {
         unlink $self->{abs_input_file};
     }
@@ -875,11 +880,6 @@ sub depak {
         unlink $self->{abs_output_file};
     }
 
-    if ($self->{test}) {
-        log_info("Testing ...");
-        $self->_test;
-    }
-
     [200, "OK", undef, {
         'func.included_modules' => $self->{_included_modules},
     }];
@@ -908,7 +908,7 @@ App::depak - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-This document describes version 0.56 of App::depak (from Perl distribution App-depak), released on 2017-07-14.
+This document describes version 0.57 of App::depak (from Perl distribution App-depak), released on 2017-07-14.
 
 =head1 SYNOPSIS
 
